@@ -3,9 +3,17 @@ import cached_url
 from telegram_util import matchKey
 
 offtopic_tags = ['nav', 'footer', 'aside', 'header']
+try:
+	credential = yaml.load('credential', Loader=yaml.FullLoader)
+except:
+	credential = {}
 
 def getSoup(site):
-	soup = BeautifulSoup(cached_url.get(site), 'html.parser')
+	if 'douban.' in site and 'douban_cookie' in credential:
+		option = {'cookie': credential.get('douban_cookie')}
+	else:
+		option = {}
+	soup = BeautifulSoup(cached_url.get(site, option), 'html.parser')
 	for item in soup.find_all('a', rel='author'):
 		item.decompose()
 	for tag in offtopic_tags:
